
#ifndef QT5GSETTINGS_EXPORT_H
#define QT5GSETTINGS_EXPORT_H

#ifdef QT5GSETTINGS_STATIC_DEFINE
#  define QT5GSETTINGS_EXPORT
#  define QT5GSETTINGS_NO_EXPORT
#else
#  ifndef QT5GSETTINGS_EXPORT
#    ifdef LIRI_BUILD_QT5GSETTINGS_LIB
        /* We are building this library */
#      define QT5GSETTINGS_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define QT5GSETTINGS_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef QT5GSETTINGS_NO_EXPORT
#    define QT5GSETTINGS_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef QT5GSETTINGS_DECL_DEPRECATED
#  define QT5GSETTINGS_DECL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef QT5GSETTINGS_DECL_DEPRECATED_EXPORT
#  define QT5GSETTINGS_DECL_DEPRECATED_EXPORT QT5GSETTINGS_EXPORT QT5GSETTINGS_DECL_DEPRECATED
#endif

#ifndef QT5GSETTINGS_DECL_DEPRECATED_NO_EXPORT
#  define QT5GSETTINGS_DECL_DEPRECATED_NO_EXPORT QT5GSETTINGS_NO_EXPORT QT5GSETTINGS_DECL_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef QT5GSETTINGS_NO_DEPRECATED
#    define QT5GSETTINGS_NO_DEPRECATED
#  endif
#endif

#define QT5GSETTINGS_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))

#if defined(QT5GSETTINGS_NO_DEPRECATED)
#  undef QT5GSETTINGS_DEPRECATED
#  define QT5GSETTINGS_DEPRECATED_EXPORT QT5GSETTINGS_EXPORT
#  define QT5GSETTINGS_DEPRECATED_NO_EXPORT QT5GSETTINGS_NO_EXPORT
#elif defined(QT5GSETTINGS_NO_DEPRECATED_WARNINGS)
#  define QT5GSETTINGS_DEPRECATED
#  define QT5GSETTINGS_DEPRECATED_EXPORT QT5GSETTINGS_EXPORT
#  define QT5GSETTINGS_DEPRECATED_NO_EXPORT QT5GSETTINGS_NO_EXPORT
#else
#  define QT5GSETTINGS_DEPRECATED QT5GSETTINGS_DECL_DEPRECATED
#  define QT5GSETTINGS_DEPRECATED_EXPORT QT5GSETTINGS_DECL_DEPRECATED_EXPORT
#  define QT5GSETTINGS_DEPRECATED_NO_EXPORT QT5GSETTINGS_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define QT5GSETTINGS_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define QT5GSETTINGS_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef QT5GSETTINGS_NO_DEPRECATED
#  define QT5GSETTINGS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x10400
#endif
#ifdef QT5GSETTINGS_NO_DEPRECATED_WARNINGS
#  define QT5GSETTINGS_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef QT5GSETTINGS_DEPRECATED_WARNINGS_SINCE
#  ifdef QT5GSETTINGS_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define QT5GSETTINGS_DEPRECATED_WARNINGS_SINCE QT5GSETTINGS_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define QT5GSETTINGS_DEPRECATED_WARNINGS_SINCE 0x10400
#  endif
#endif

#ifndef QT5GSETTINGS_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define QT5GSETTINGS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x10000
#endif

#ifdef QT5GSETTINGS_DEPRECATED
#  define QT5GSETTINGS_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > QT5GSETTINGS_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define QT5GSETTINGS_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif


#endif /* QT5GSETTINGS_EXPORT_H */
