// SPDX-FileCopyrightText: 2022 Pier Luigi Fiorini <pierluigi.fiorini@gmail.com>
//
// SPDX-License-Identifier: BSD-3-Clause

/* This file was generated by liri_add_module(). */

#ifndef LIRIQT5GSETTINGS_VERSION_H
#define LIRIQT5GSETTINGS_VERSION_H

#define LIRIQT5GSETTINGS_VERSION_STR "1.4.0"

#define LIRIQT5GSETTINGS_VERSION ((1<<16)|(4<<8)|(0)))

#endif // LIRIQT5GSETTINGS_VERSION_H
